<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About MystiQ</source>
        <translation>Om MystiQ</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Översättare</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <source>Portable</source>
        <translation>Portabel</translation>
    </message>
    <message>
        <source>Compiled with Qt %1</source>
        <translation>Kompilerad med Qt %1</translation>
    </message>
    <message>
        <source>Compiled with libnotify %1</source>
        <translation>Kompilerad med libnotify %1</translation>
    </message>
    <message>
        <source>MystiQ Homepage: %1</source>
        <translation>MystiQ hemsida: %1</translation>
    </message>
    <message>
        <source>Some audio-processing functionalities are provided by SoX.</source>
        <translation>Vissa ljudbearbetningsfunktioner tillhandahålles av SoX.</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <extracomment>Spanish Language (Spain)</extracomment>
        <translation>Spanska (Spanien)</translation>
    </message>
    <message>
        <source>MystiQ is a GUI frontend for FFmpeg.</source>
        <translation>MystiQ är ett användargränssnitt för FFmpeg.</translation>
    </message>
    <message>
        <source>Developers:&lt;br&gt; %1</source>
        <translation>Utvecklare:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <extracomment>Swedish Language (Sweden)</extracomment>
        <translation>Svenska (Sverige)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <extracomment>Japanese Language (Japan)</extracomment>
        <translation>Japanska (Japan)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <extracomment>German Language (Germany)</extracomment>
        <translation>Tyska (Tyskland)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <extracomment>Italian Language (Italy)</extracomment>
        <translation></translation>
    </message>
    <message>
        <source>Application Name:&lt;br&gt; %1</source>
        <translation>Programnamn:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 3.</source>
        <translation>Detta program är fri mjukvara! Du kan återdistribuera och/eller modifiera det, under villkoren för GNU General Public License version 3.</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <extracomment>Turkish Language (Turkey)</extracomment>
        <translation>Turkiska (Turkiet)</translation>
    </message>
    <message>
        <source>Many people have contributed translations. You can also help translate the MystiQ Video Converter into your own language. Visit </source>
        <translation>Många har hjälpt till att översätta MystiQ Video Converter. Du kan också hjälpa till att översätta till ditt eget språk. Besök </translation>
    </message>
    <message>
        <source> and join a translation team.</source>
        <translation> och gå med i en översättningsgrupp.</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <source>Hungarian (Hungary)</source>
        <extracomment>Hungarian Language (Hungary)</extracomment>
        <translation>Ungerska (Ungern)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <extracomment>Russian Language (Russia)</extracomment>
        <translation>Ryska (Ryssland)</translation>
    </message>
    <message>
        <source>Collaborators:&lt;br&gt; %1</source>
        <translation>Medarbetare:&lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Some features of MystiQ Video Converter have been inspired by</source>
        <translation>Vissa funktioner i MystiQ Video Converter har inspirerats av</translation>
    </message>
    <message>
        <source>Galician (Galicia)</source>
        <extracomment>Galician Language (Galicia)</extracomment>
        <translation>Galiciska (Galicien)</translation>
    </message>
    <message>
        <source>Icons Theme:&lt;br&gt; %1</source>
        <translation>Ikoner Tema: &lt;br&gt; %1</translation>
    </message>
    <message>
        <source>Indonesian (Indonesia)</source>
        <extracomment>Indonesian Language (Indonesia)</extracomment>
        <translation>Indonesiska (Indonesien)</translation>
    </message>
</context>
<context>
    <name>AboutFFmpegDialog</name>
    <message>
        <source>About FFmpeg</source>
        <translation>Om FFmpeg</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Available Codecs</source>
        <translation>Tillgängliga kodekar</translation>
    </message>
    <message>
        <source>FFmpeg is a complete, cross-platform solution to record, convert and stream audio and video. It includes libavcodec - the leading audio/video codec library.</source>
        <extracomment>ffmpeg description</extracomment>
        <translatorcomment>FFmpeg Beschreibung</translatorcomment>
        <translation>FFmpeg är en komplett, plattformsöverskridande lösning för att spela in, konvertera och strömma ljud och film. Den inkluderar libavcodec - Det ledande biblioteket för ljud-/videokodekar.</translation>
    </message>
    <message>
        <source>FFmpeg is free software licensed under the LGPL or GPL.</source>
        <translation>FFmpeg är fri mjukvara licensierad under LGPL eller GPL.</translation>
    </message>
    <message>
        <source>Please visit %1 for more information.</source>
        <translation>Besök %1 för mer information.</translation>
    </message>
</context>
<context>
    <name>AddTaskWizard</name>
    <message>
        <source>Add Tasks</source>
        <translation>Lägg till arbetsuppgifter</translation>
    </message>
    <message>
        <source>Files to be converted</source>
        <translation>Filer att konvertera</translation>
    </message>
    <message>
        <source>Add files.</source>
        <translation>Lägg till filer.</translation>
    </message>
    <message>
        <source>Remove selected files.</source>
        <translation>Ta bort markerade filer.</translation>
    </message>
    <message>
        <source>Output Settings</source>
        <translation>Utdatainställningar</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Redigera</translation>
    </message>
    <message>
        <source>Auto adjust output bitrate to reduce output file size.</source>
        <translation>Justera utdatans bithastighet automatiskt, för att reducera filstorleken.</translation>
    </message>
    <message>
        <source>Auto Adjust Audio Bitrate</source>
        <translation>Autojustera ljudets bithastighet</translation>
    </message>
    <message>
        <source>Preset</source>
        <translation>Förinställning</translation>
    </message>
    <message>
        <source>Convert to</source>
        <translation>Konvertera till</translation>
    </message>
    <message>
        <source>Output Path</source>
        <translation>Utdatasökväg</translation>
    </message>
    <message>
        <source>Select &amp;folder</source>
        <translation>Välj &amp;mapp</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bläddra</translation>
    </message>
    <message>
        <source>Create &amp;new folder in source folder</source>
        <extracomment>Create a new folder (e.g. mystiq_output) in the folder containing the input files. Put the output files in the newly created folder.</extracomment>
        <translation>Skapa en &amp;ny mapp i källmappen</translation>
    </message>
    <message>
        <source>Folder Name</source>
        <translation>Mappnamn</translation>
    </message>
    <message>
        <source>Output to &amp;source folder</source>
        <extracomment>put the output files in the same folder as the input files</extracomment>
        <translation>Utdata till &amp;källmappen</translation>
    </message>
    <message>
        <source>Please select at least one file.</source>
        <translation>Välj minst en fil.</translation>
    </message>
    <message>
        <source>Select Files</source>
        <extracomment>This text is the title of an openfile dialog.</extracomment>
        <translation>Välj filer</translation>
    </message>
    <message>
        <source>Multimedia</source>
        <translation>Multimedia</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ljud</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alla filer</translation>
    </message>
    <message>
        <source>Select Directory</source>
        <extracomment>This text is the title of an open directory dialog.</extracomment>
        <translatorcomment>Dieser Text ist der Titel eines Dialogfelds für geöffnete Ordner.</translatorcomment>
        <translation>Välj mapp</translation>
    </message>
    <message>
        <source>Searching for files...</source>
        <translation>Söker efter filer...</translation>
    </message>
    <message>
        <source>Some files could not be found.</source>
        <translation>Vissa filer kunde inte hittas.</translation>
    </message>
    <message>
        <source>Folder does not exist. Create a new folder?</source>
        <translation>Mappen finns inte. Vill du skapa en ny mapp?</translation>
    </message>
    <message>
        <source>Failed to create folder. Please select another output folder.</source>
        <translation>Kunde inte skapa mappen. Välj en annan utdatamapp.</translation>
    </message>
    <message>
        <source>Add Files</source>
        <translation>Lägg till filer</translation>
    </message>
    <message>
        <source>Remove Selected</source>
        <translation>Ta bort markerat</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Rensa listan</translation>
    </message>
</context>
<context>
    <name>ConversionParameterDialog</name>
    <message>
        <source>Conversion Parameters</source>
        <translation>Konverteringsparametrar</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Ljud</translation>
    </message>
    <message>
        <source>Disable Audio</source>
        <translation>Inaktivera ljud</translation>
    </message>
    <message>
        <source>Audio Options</source>
        <translation>Ljudalternativ</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Samplingsfrekvens</translation>
    </message>
    <message>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation>Bithastighet</translation>
    </message>
    <message>
        <source>(auto)</source>
        <translation>(auto)</translation>
    </message>
    <message>
        <source>kb/s</source>
        <translation>kb/s</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Kanaler</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Volym</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Disable Video</source>
        <translation>Inaktivera video</translation>
    </message>
    <message>
        <source>Video Options</source>
        <translation>Videoalternativ</translation>
    </message>
    <message>
        <source>Same Quantizer as Source</source>
        <translation>Samma kvantiserare som källan</translation>
    </message>
    <message>
        <source>Deinterlace</source>
        <translation>Avfläta</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Bredd</translation>
    </message>
    <message>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Höjd</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Beskär</translation>
    </message>
    <message>
        <source>Time</source>
        <extracomment>time-related options (speed, length)</extracomment>
        <translation>Tid</translation>
    </message>
    <message>
        <source>Cutting</source>
        <extracomment>video time cutting: options for begin time and end time</extracomment>
        <translation>Klippning</translation>
    </message>
    <message>
        <source>Cut</source>
        <comment>Cut video; select a range to convert</comment>
        <translation>Klipp</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Förhandsgranska</translation>
    </message>
    <message>
        <source>Scaling</source>
        <extracomment>time scaling, changing the speed of the output file</extracomment>
        <translation>Skalning</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hastighet</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avancerat</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Additional FFmpeg Options</source>
        <translation>Fler FFmpeg-alternativ</translation>
    </message>
    <message>
        <source>Copy Audio (Do not re-encode)</source>
        <translation>Kopiera ljud (ingen omkodning)</translation>
    </message>
    <message>
        <source>Insert Subtitle if Available</source>
        <translation>Infoga undertext om tillgänglig</translation>
    </message>
    <message>
        <source>Copy Video (Do not re-encode)</source>
        <translation>Kopiera video (ingen omkodning)</translation>
    </message>
    <message>
        <source>qrc:/qml/main.qml</source>
        <translation>qrc:/qml/main.qml</translation>
    </message>
    <message>
        <source>Video Extra Options</source>
        <translation>Extra videoalternativ</translation>
    </message>
    <message>
        <source>Video to Black and White</source>
        <translation>Video till svartvitt</translation>
    </message>
    <message>
        <source>Vertical Flip</source>
        <translation>Vertikal vändning</translation>
    </message>
    <message>
        <source>Horizontal Flip</source>
        <translation>Horisontell vändning</translation>
    </message>
    <message>
        <source>Rotate 90 degrees clockwise</source>
        <translation>Rotera 90 grader medurs</translation>
    </message>
    <message>
        <source>Rotate 90 degrees counterclockwise</source>
        <translation>Rotera 90 grader moturs</translation>
    </message>
    <message>
        <source>Rotate 180 degrees</source>
        <translation>Rotera 180 grader</translation>
    </message>
    <message>
        <source>3D Options</source>
        <translation>3D-alternativ</translation>
    </message>
    <message>
        <source>Red Blue Gray Monochromatic</source>
        <translation>Röd Blå Grå monokromatisk</translation>
    </message>
    <message>
        <source>Red Cyan Dubois</source>
        <translation>Röd Cyan Dubois</translation>
    </message>
    <message>
        <source>Green Magenta Color</source>
        <translation>Grön Magenta Färg</translation>
    </message>
    <message>
        <source>Red Cyan Half Color</source>
        <translation>Röd Cyan Halvfärg</translation>
    </message>
    <message>
        <source>Yellow Blue Color</source>
        <translation>Gul Blå Färg</translation>
    </message>
    <message>
        <source>Red Cyan Color</source>
        <translation>Röd Cyan Färg</translation>
    </message>
    <message>
        <source>Green Magenta Gray Monochromatic</source>
        <translation>Grön Magenta Grå Monokromatisk</translation>
    </message>
    <message>
        <source>Red Green Gray Monochromatic</source>
        <translation>Röd Grön Grå Monokromatisk</translation>
    </message>
    <message>
        <source>None</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ConvertList</name>
    <message>
        <source>Cancel</source>
        <extracomment>Cancel the operation of adding new tasks</extracomment>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Adding files (%1/%2)</source>
        <extracomment>This text is the progress indicator of adding multiple tasks. %1 is the number of files that are already added. %2 is the total number of files.</extracomment>
        <translation>Lägger till filer (%1/%2)</translation>
    </message>
    <message>
        <source>Some files are not recognized by the converter.</source>
        <translation>Vissa filer känns inte igen av konverteraren.</translation>
    </message>
    <message>
        <source>New File Name</source>
        <translation>Nytt filnamn</translation>
    </message>
    <message>
        <source>Please input the new name for the output file.</source>
        <translation>Ange nytt namn på utdatafilen.</translation>
    </message>
    <message>
        <source>Output Directory</source>
        <translation>Utdatamapp</translation>
    </message>
    <message>
        <source>Error Message from FFmpeg:

</source>
        <translation>Felmeddelande från FFmpeg:

</translation>
    </message>
    <message>
        <source>Drag and drop files here to add tasks.</source>
        <translation>Dra och släpp filer här, för att lägga till arbetsuppgifter.</translation>
    </message>
    <message>
        <source>Hide &quot;%1&quot;</source>
        <extracomment>Hide a column in the list. For example, the text maybe &apos;Hide &quot;Duration&quot;&apos;. The two &quot; are quotation marks in English, you may replace it with local quotation marks.</extracomment>
        <translation>Dölj &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Restore All Columns</source>
        <translation>Återställ alla kolumner</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Källa</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Mål</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Varaktighet</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Filstorlek</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <extracomment>Audio</extracomment>
        <translation>Samplingsfrekvens</translation>
    </message>
    <message>
        <source>Audio Bitrate</source>
        <translation>Bithastighet ljud</translation>
    </message>
    <message>
        <source>Channels</source>
        <extracomment>Audio</extracomment>
        <translatorcomment>Audio</translatorcomment>
        <translation>Kanaler</translation>
    </message>
    <message>
        <source>Audio Codec</source>
        <translation>Ljudkodek</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensioner</translation>
    </message>
    <message>
        <source>Video Bitrate</source>
        <translation>Bithastighet video</translation>
    </message>
    <message>
        <source>Framerate</source>
        <extracomment>Video</extracomment>
        <translation>Bildfrekvens</translation>
    </message>
    <message>
        <source>Video Codec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Förlopp</translation>
    </message>
    <message>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
    <message>
        <source>%1 kb/s</source>
        <translation>%1 kb/s</translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <source>Removing tasks...</source>
        <extracomment>Remove files from the tasklist</extracomment>
        <translation>Tar bort arbetsuppgifter...</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Bytes</extracomment>
        <translatorcomment>Bytes</translatorcomment>
        <translation>B</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Filen finns redan</translation>
    </message>
    <message>
        <source>%1 already exists on disk or in the task list. Still use this name as the output filename?</source>
        <translation>%1 finns redan på disken eller i arbetslistan. Vill du fortfarande använda detta filnamn på utdatafilen?</translation>
    </message>
    <message>
        <source>Remove Task</source>
        <translation>Ta bort arbetsuppgift</translation>
    </message>
    <message>
        <source>Cannot remove a task while it is in progress.</source>
        <translation>Kan inte ta bort en arbetsuppgift som pågår.</translation>
    </message>
    <message>
        <source>Finished</source>
        <extracomment>The text to be displayed on the progress bar when a conversion finishes</extracomment>
        <translation>Slutförd</translation>
    </message>
    <message>
        <source>Failed</source>
        <extracomment>The text to be displayed on the progress bar when a conversion fails</extracomment>
        <translation>Misslyckad</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <extracomment>%1 is the error message</extracomment>
        <translation>Fel: %1</translation>
    </message>
</context>
<context>
    <name>ExtraTranslations</name>
    <message>
        <source>Convert between media file formats</source>
        <translation>Konvertera mellan mediafilsformat</translation>
    </message>
    <message>
        <source>Media Converter</source>
        <translation>Mediakonverterare</translation>
    </message>
</context>
<context>
    <name>HelpMystiQDialog</name>
    <message>
        <source>User Manual</source>
        <translation>Användarmanual</translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Fira Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;MystiQ User&apos;s Manual&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/mystiq_96x96.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is a cross platform application. This application has as its sole objective the conversion of audio and video files to multiple formats. As a distinctive feature, MystiQ is an open source project, which means that the source code will always be available and everyone who wishes to contribute to the development is welcome.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is free: you can redistribute it and / or modify it under the terms GNU (General Public License) published by the Free Software Foundation. MystiQ Video Converter is freely distributed with the sole purpose of being a useful application to your needs, but WITHOUT NO WARRANTY, even if its use is COMMERCIAL or MERELY A PARTICULAR PURPOSE See the GPL v3 license for more details. This application includes an English copy of the Software distribution license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The essential idea of ​​the development team is to provide a friendly and simple user interface. The simple is the essence of MystiQ, which means that it is not our objective to add features that complicate the operation of the application.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Currently MystiQ is mainly developed in C ++ taking advantage of the Qt5 graphic libraries. In the FFmpeg backend he is in charge of converting between formats, so we can say that MystiQ is simply a graphical interface for FFmpeg.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ currently allows you to convert to most existing video formats, as well as make it possible to extract audio and convert between audio formats. It also includes a small tool to trim videos based on the duration of these.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter currently supports the following audio and video formats:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Audio: mp3 m4a 3g2 ogg wav wma  ac3 ra ape flac opus&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Video: avi vfw divx mpg mpeg m1v m2v mpv dv 3gp mov mp4 m4v mqv dat vcd ogg ogm ogv asf wmv bin iso vob mkv nsv ram flv rm swf ts rmvb dvr-ms m2t m2ts rec mts webm dv&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot1.png&quot; /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Toolbar&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;In the upper part of the main window of the application we will find the toolbar with the following buttons:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot2.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;ul style=&quot;margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;&quot;&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Add Files:&lt;/span&gt; &lt;span style=&quot; font-size:12pt;&quot;&gt;Opens a dialog to select the video files you want to convert. Once selected, they are placed in the List of Conversion Tasks&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Start: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Start conversion process from the list of loaded items&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Stop: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Stops the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry All:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the conversion process of all items in the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Selected:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove a selected item from the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Completed:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the list that have completed the conversion process&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Clear List:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the conversion list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Open Output Folder: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;From the system file manager open the folder that contains the converted files&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot; font-size:12pt;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Power Options:&lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;  &lt;/span&gt;Choose whether to shut down, suspend or hibernate the computer when completing the conversion process of all items in the list&lt;/li&gt;&lt;/ul&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Audio Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot3.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Audio:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding sound.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Copy audio (do not recode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the audio from the source file. The resulting file will have the same sound parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Sample Rate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; In audio production, a sample rate (or &amp;quot;sampling rate&amp;quot;) defines how many times per second a sound is sampled. Technically speaking, it is the frequency of samples used in a digital recording.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Bitrate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; It&apos;s the bit rate or data that is processed per unit of time. The average bitrate for an MP3 file is 128 kbits per second or kbps.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Channels: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the passage way a signal or data is transported. In case of audio files, it&apos;s the passage or communication channel in which a sound signal is transported from the player source to the speaker. An audio file can contain one, two or even more Channels.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Volume: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Allows you to configure the maximum volume of the destination file taking as a match the volume level of the source file.&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Video Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Insert Subtitle if Available: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;By checking this option, the application will verify if a subtitle file of the same name is found in the same location of the source file, if found, it will embed it in the resulting file. It is currently compatible with subtitles in SRT, SSA, ASS and SUB format.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Video:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding video.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Copy Video (Do not re-encode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the video from the source file. The resulting file will have the same video parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Video to Black and White: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It allows to obtain a video file is grayscale.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Flip and Rotate options: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The resulting file will be rotated or flipped in the direction chosen.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Deinterlace: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the process of converting interlaced video, such as common analog television signals or 1080i format HDTV signals, into a non-interlaced form. An interlaced video frame consists of two sub-fields taken in sequence, each sequentially scanned at odd, and then even, lines of the image sensor.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Same Quantizer as source: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s involved in image processing, is a lossy compression technique achieved by compressing a range of values to a single quantum value. Checking this option the resulting file will have the same deinterlacing as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Fira Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;MystiQ användarmanual&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/mystiq_96x96.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter är ett plattformsöverskridande program. Detta program har som enda syfte att omvandla ljud- och videofiler till flera olika format. Som utmärkande drag är MystiQ ett öppen-källkods-projekt, vilket innebär att källkoden alltid kommer att finnas tillgänglig och att alla som vill bidra till utvecklingen är välkomna.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter är fri programvara! Du kan återdistribuera och/eller modifiera det, under villkoren för GNU General Public License som den publiceras av Free Software Foundation. MystiQ Video Converter distribueras i hopp om att det skall vara användbart, men UTAN NÅGRA GARANTIER. Utan ens underförstådd garanti om SÄLJBARHET eller LÄMPLIGHET FÖR ETT VISST ÄNDAMÅL. Se GPL v3 för mer detaljerad info. Programmet inkluderar en Engelsk kopia av mjukvarans distributionslicens.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Den grundläggande idén med utvecklingen är att erbjuda ett användarvänligt och enkelt användargränssnitt. Det enkla är essensen av MystiQ, vilket innebär att det inte är vårt mål att lägga till funktioner som komplicerar användningen av programmet.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;För närvarande är MystiQ främst utvecklad i C++ som drar fördel av qt5-grafikbibliotek. I FFmpeg ansvarar det för att konvertera mellan olika format, så vi kan säga att MystiQ helt enkelt är ett grafiskt gränssnitt för FFmpeg.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ låter dig för närvarande konvertera till de flesta befintliga videoformat, samt gör det möjligt att extrahera ljud och konvertera mellan ljudformat. Det innehåller också ett litet verktyg för att trimma videor baserat på dess varaktighet.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter stödjer för närvarande följande ljud- och videoformat:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Ljud: mp3 m4a 3g2 ogg wav wma  ac3 ra ape flac opus&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Video: avi vfw divx mpg mpeg m1v m2v mpv dv 3gp mov mp4 m4v mqv dat vcd ogg ogm ogv asf wmv bin iso vob mkv nsv ram flv rm swf ts rmvb dvr-ms m2t m2ts rec mts webm dv&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot1.png&quot; /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Verktygsfält&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;I den övre delen av programmets huvudfönster hittar vi verktygsfältet med följande knappar:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot2.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;ul style=&quot;margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;&quot;&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Lägg till filer:&lt;/span&gt; &lt;span style=&quot; font-size:12pt;&quot;&gt;Öppnar en dialogruta för att välja de videofiler du vill konvertera. När de har valts placeras de i listan över arbetsuppgifter.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Starta: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Startar konverteringsprocessen från listan över inlästa objekt.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Stoppa: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Stoppar konverteringsprocessen för ett objekt.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Försök igen:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Försöker igen, att konvertera ett objekt.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Försök alla igen:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Försöker igen, att konvertera alla objekt i listan.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Ta bort markerat:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Tar bort ett markerat objekt från listan.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Ta bort slutfört:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Tar bort alla objekt som har slutfört konverteringsprocessen, från listan.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Rensa listan:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Tar bort alla objekt från konverteringslistan.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Öppna utdatamappen: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Öppnar mappen som innehåller de konverterade filerna, i systemets filhanterare.&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot; font-size:12pt;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Energialternativ:&lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;  &lt;/span&gt;Välj om du vill stänga av, eller försätta datorn i viloläge/vänteläge när du slutfört konverteringsprocessen av alla objekt i listan.&lt;/li&gt;&lt;/ul&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Ljudalternativ&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot3.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Inaktivera ljud:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;  Gör att du kan få en resultatfil utan ljud.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Kopiera ljud (koda inte om):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Gör att du kan konvertera utan att bearbeta ljudet från källfilen. Den resulterande filen har samma ljudparametrar som källfilen.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Samplingsfrekvens:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; I ljudproduktion definieras en samplingshastighet (eller &amp;quot;samplingsfrekvens&amp;quot;) hur många gånger per sekund ett ljud samplas. Tekniskt sett är det samplingsfrekvensen som används i en digital inspelning.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Bithastighet:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Det är den bithastighet eller data som bearbetas per tidsenhet. Den genomsnittliga bithastigheten för en MP3-fil är 128 kbits per sekund eller kbps.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Kanaler: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Det är den passage som en signal eller data transporteras. När det gäller ljudfiler är det passage- eller kommunikationskanalen där en ljudsignal transporteras från spelarkällan till högtalaren. En ljudfil kan innehålla en, två eller flera kanaler.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Volym: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Gör att du kan konfigurera den maximala volymen för målfilen som en matchning av källfilens volymnivå.&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Videoalternativ&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Infoga undertext om tillgänglig: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Genom att aktivera det här alternativet verifierar programmet om en undertextfil med samma namn hittas på samma plats som källfilen, om den hittas, kommer den att bäddas in i den resulterande filen. Det är för närvarande kompatibelt med undertexter i formaten SRT, SSA, ASS och SUB.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Inaktivera Video:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Gör att du kan få en resultatfil utan video.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Kopiera video (koda inte om):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Gör att du kan konvertera utan att bearbeta videon från källfilen. Den resulterande filen har samma videoparametrar som källfilen.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Video till svartvitt: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Det gör det möjligt att få en videofil är gråskala.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Alternativ för Vänd och Rotera: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Resultatfilen roteras eller vänds i den riktning som valts.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Avfläta: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Det är en process för att omvandla sammanflätad video, såsom vanliga analoga TV-signaler eller 1080i-formats HDTV-signaler, till en icke-sammanflätad form. En sammanflätad bildruta består av två underfält tagna i sekvensrader av bildsensorn, var för sig sekventiellt skannad.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Samma kvantiserare som källan: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Det här ingår i bildbehandlingen och är en förstörande komprimeringteknik som uppnås genom att komprimera ett värdeintervall till ett enda kvantvärde. Om du markerar det här alternativet kommer resultatfilen att ha samma avflätning som källfilen.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>InteractiveCuttingDialog</name>
    <message>
        <source>Cutting</source>
        <comment>Cutting as in &quot;cutting video&quot;</comment>
        <translation>Klippning</translation>
    </message>
    <message>
        <source>Mark as Begin</source>
        <translation>Markera som början</translation>
    </message>
    <message>
        <source>Seek to Begin</source>
        <translation>Gå till början</translation>
    </message>
    <message>
        <source>Play Selection</source>
        <translation>Spela upp markerat</translation>
    </message>
    <message>
        <source>Mark as End</source>
        <translation>Markera som slut</translation>
    </message>
    <message>
        <source>Seek to End</source>
        <translation>Gå till slutet</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Start conversion process.</source>
        <translation>Starta konverteringsprocessen.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Arkiv</translation>
    </message>
    <message>
        <source>&amp;Convert</source>
        <translation>&amp;Konvertera</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Redigera</translation>
    </message>
    <message>
        <source>&amp;Add Files</source>
        <translation>&amp;Lägg till filer</translation>
    </message>
    <message>
        <source>Add files for conversion.</source>
        <translation>Lägg till filer för konvertering.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>A&amp;vsluta</translation>
    </message>
    <message>
        <source>Exit the program.</source>
        <translation>Avsluta programmet.</translation>
    </message>
    <message>
        <source>S&amp;top</source>
        <translation>&amp;Stoppa</translation>
    </message>
    <message>
        <source>Stop conversion process.</source>
        <translation>Stoppa konverteringsprocessen.</translation>
    </message>
    <message>
        <source>Set &amp;Parameters</source>
        <translation>Ange &amp;parametrar</translation>
    </message>
    <message>
        <source>Set Parameters</source>
        <extracomment>Edit output file parameters.</extracomment>
        <translation>Ange parametrar</translation>
    </message>
    <message>
        <source>Edit conversion parameters of selected files.</source>
        <translation>Redigera konverteringsparametrar för markerad fil.</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Om&amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Om Qt</translation>
    </message>
    <message>
        <source>&amp;Open Output Folder</source>
        <translation>&amp;Öppna utdatamappen</translation>
    </message>
    <message>
        <source>Open output folder of the selected file.</source>
        <translation>Öppna utdatamappen för markerad fil.</translation>
    </message>
    <message>
        <source>About &amp;FFmpeg</source>
        <translation>Om &amp;FFmpeg</translation>
    </message>
    <message>
        <source>About FFmpeg</source>
        <translation>Om FFmpeg</translation>
    </message>
    <message>
        <source>&amp;Remove Selected</source>
        <extracomment>remove selected (tasks, items)</extracomment>
        <translation>&amp;Ta bort markerat</translation>
    </message>
    <message>
        <source>Remove all selected items in the list.</source>
        <translation>Ta bort alla markerade objekt från listan.</translation>
    </message>
    <message>
        <source>R&amp;emove Completed</source>
        <extracomment>remove completed (task, items)</extracomment>
        <translation>Ta bort &amp;slutförda</translation>
    </message>
    <message>
        <source>Remove Completed Items</source>
        <translation>Ta bort slutförda objekt</translation>
    </message>
    <message>
        <source>Remove all completed items in the list.</source>
        <translation>Ta bort alla slutförda objekt från listan.</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Rensa listan</translation>
    </message>
    <message>
        <source>Remove all items in the list.</source>
        <translation>Ta bort alla objekt från listan.</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Försök igen</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Försök igen</translation>
    </message>
    <message>
        <source>Retry selected tasks.</source>
        <translation>Försök igen med markerade objekt.</translation>
    </message>
    <message>
        <source>Retry &amp;All</source>
        <translation>Försök &amp;alla igen</translation>
    </message>
    <message>
        <source>Retry all tasks.</source>
        <translation>Försök igen med alla objekt.</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Alternativ</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Alternativ</translation>
    </message>
    <message>
        <source>About This Program</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <source>Change Output &amp;Filename</source>
        <translation>Byt namn på &amp;utdatafil</translation>
    </message>
    <message>
        <source>Change the output filename of the selected item.</source>
        <translation>Ändra utdatafilnamn på markerat objekt.</translation>
    </message>
    <message>
        <source>Change Output &amp;Directory</source>
        <translation>Byt utdata&amp;mapp</translation>
    </message>
    <message>
        <source>Change the output directory of the selected items.</source>
        <translation>Ändra utdatamapp för markerade objekt.</translation>
    </message>
    <message>
        <source>Show Error &amp;Message</source>
        <translation>Visa fel&amp;meddelanden</translation>
    </message>
    <message>
        <source>Check For &amp;Updates</source>
        <translation>Sök efter &amp;uppdateringar</translation>
    </message>
    <message>
        <source>Cut</source>
        <extracomment>Cut video file (select a time range to conert)</extracomment>
        <translation>Klipp</translation>
    </message>
    <message>
        <source>All tasks have finished.</source>
        <translation>Alla åtgärder har slutförts.</translation>
    </message>
    <message>
        <source>Nothing to convert.</source>
        <translation>Inget att konvertera.</translation>
    </message>
    <message>
        <source>Conversion is still in progress. Abort?</source>
        <translation>Kovertering pågår fortfarande. Vill du avbryta?</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer (completely poweroff)</extracomment>
        <translation>Stäng av</translation>
    </message>
    <message>
        <source>Shutdown when all tasks are done.</source>
        <translation>Stäng av datorn när alla åtgärder har slutförts.</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Vänteläge</translation>
    </message>
    <message>
        <source>Suspend when all tasks are done.</source>
        <translation>Försätt datorn i vänteläge när alla åtgärder har slutförts.</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Viloläge</translation>
    </message>
    <message>
        <source>Hibernate when all tasks are done.</source>
        <translation>Försätt datorn i viloläge när alla åtgärder har slutförts.</translation>
    </message>
    <message>
        <source>This program is going to check for updates online. Do you allow this program to use the Internet to check for updates?</source>
        <translation>Detta program kommer att söka efter uppdateringar online. Vill du tillåta programmet att använda internet för uppdateringar?</translation>
    </message>
    <message>
        <source>Failed to load preset file. The application will quit now.</source>
        <translation>Kunde inte läsa in förinställningsfilen. Programmet kommer att avslutas nu.</translation>
    </message>
    <message>
        <source>Elapsed Time: %1 h %2 m %3 s</source>
        <translation>Förfluten tid: %1 t %2 m %3 s</translation>
    </message>
    <message>
        <source>MystiQ Media Converter</source>
        <translation>MystiQ Media Converter</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjälp</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Clear &amp;List</source>
        <translation>Rensa &amp;listan</translation>
    </message>
    <message>
        <source>About MystiQ</source>
        <translation>Om MystiQ</translation>
    </message>
    <message>
        <source>Poweroff</source>
        <translation>Avstängning</translation>
    </message>
    <message>
        <source>User Manual</source>
        <translation>Användarmanual</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>&amp;Report Error</source>
        <translation>&amp;Rapportera fel</translation>
    </message>
    <message>
        <source>Report Error</source>
        <translation>Rapportera fel</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donera</translation>
    </message>
    <message>
        <source>Conversion failed.</source>
        <translation>Konvertering misslyckades.</translation>
    </message>
    <message>
        <source>Support MystiQ</source>
        <translation>Stöd MystiQ</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <source>MystiQ needs you</source>
        <translation>MystiQ behöver dig</translation>
    </message>
    <message>
        <source>MystiQ is free software. However the development requires a lot of time and a lot of work. In order to keep developing MystiQ with new features we need your help. Please consider to support the MystiQ project by sending a donation. &lt;b&gt;Even the smallest amount will help a lot.&lt;/b&gt;</source>
        <translation>MystiQ är fri programvara. Utvecklingen kräver dock mycket tid och mycket arbete. Vi behöver din hjälp för att kunna utveckla MystiQ med nya funktioner. Överväg gärna att stödja projektet genom att skicka en donation. &lt;b&gt;Även den minsta summa, hjälper mycket.&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Reporting bugs from MystiQ </source>
        <translation>Rapportera fel i MystiQ </translation>
    </message>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Your comment:</source>
        <translation>Din kommentar:</translation>
    </message>
    <message>
        <source>Report:</source>
        <translation>Rapport:</translation>
    </message>
    <message>
        <source>MystiQ is Converting %1/%2</source>
        <extracomment>Converting the %1-th file in %2 files. %2 is the number of files.</extracomment>
        <translation>MystiQ konverterar %1/%2</translation>
    </message>
    <message>
        <source>MystiQ Video Converter</source>
        <translation>MystiQ Video Converter</translation>
    </message>
    <message>
        <source>Conversion finished successfully.</source>
        <translation>Konverteringen slutfördes korrekt.</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Översätt</translation>
    </message>
    <message>
        <source>Translate Application</source>
        <translation>Översätt programmet</translation>
    </message>
    <message>
        <source>Report Bugs</source>
        <translation>Rapportera fel</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-post</translation>
    </message>
    <message>
        <source>We need your feedback</source>
        <translation>Vi behöver din återkoppling</translation>
    </message>
    <message>
        <source>Github</source>
        <translation>GitHub</translation>
    </message>
    <message>
        <source>MystiQ Video Converter development team needs users who use the application to help detect errors. If you find an error and report it to our team, it will help speed up the correction process. Therefore, you can be part of our development team even if you are not a developer. To report an error, you can send us an email with the detailed description of it or you can enter Github and describe the issue (in this case you must have a GitHub Account).</source>
        <translation>MystiQ Video Converters utvecklingsgrupp behöver användare som använder programmet, för att upptäcka fel. Om du hittar ett fel och rapporterar det till vår grupp, kommer det att bidra till att påskynda korrigeringsprocessen. Därför kan du vara en del av vår utvecklingsgrupp även om du inte är utvecklare. Om du vill rapportera ett fel kan du skicka ett e-postmeddelande med en detaljerad beskrivning av felet eller också kan du logga in på GitHub och beskriva problemet ( i det fallet måste du ha ett GitHub-konto).</translation>
    </message>
    <message>
        <source>Gitter</source>
        <translation>Gitter</translation>
    </message>
</context>
<context>
    <name>MediaConverter</name>
    <message>
        <source> FFmpeg or FFprobe %1 have not been found in the system. Please consider installing them before running MystiQ</source>
        <extracomment>%1 is a computer program</extracomment>
        <translation> FFmpeg eller FFprobe %1 kan inte hittas i systemet. Överväg att installera dem innan du kör MystiQ</translation>
    </message>
</context>
<context>
    <name>MediaPlayerWidget</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Alternativ</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allmänt</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Sök efter uppdateringar vid programstart</translation>
    </message>
    <message>
        <source>Automatically start conversion after adding files to the list.</source>
        <translation>Starta konvertering automatiskt när filer läggs till i listan.</translation>
    </message>
    <message>
        <source>Start conversion automatically</source>
        <translation>Starta konvertering automatiskt</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Number of threads to use in conversion</source>
        <translation>Antal trådar att använda vid konvertering</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Hide output formats that are not available in the current ffmpeg installation. It is recommended to turn this option on unless you are sure that MystiQ has failed to detect available formats. (requires restarting MystiQ to take effect)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Dölj utdataformat som inte finns tillgängliga i aktuell ffmpeg-installation. Det rekommenderas att detta alternativ aktiveras, om du inte är säker på att MystiQ har misslyckats med att upptäcka tillgängliga format (kräver omstart av MystiQ för att få effekt).&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Hide unavailable formats (requires restarting)</source>
        <translation>Dölj icke tillgängliga format (kräver omstart)</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Verktyg</translation>
    </message>
    <message>
        <source>You have to restart MystiQ for the changes to take effect.</source>
        <translation>Du måste starta om MystiQ för att ändringarna skall tillämpas.</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Kommando</translation>
    </message>
</context>
<context>
    <name>PoweroffDialog</name>
    <message>
        <source>MystiQ</source>
        <translation>MystiQ</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Shutdown immediately</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Stäng av datorn</translation>
    </message>
    <message>
        <source>Suspend immediately</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Försätt datorn i vänteläge</translation>
    </message>
    <message>
        <source>Hibernate immediately</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Försätt datorn i viloläge</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Stäng av</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Vänteläge</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Viloläge</translation>
    </message>
    <message>
        <source>Operation Failed: %1</source>
        <translation>Åtgärden misslyckades: %1</translation>
    </message>
    <message>
        <source>Shutting down in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Stänger av om &lt;b&gt;%1&lt;/b&gt; sekunder</translation>
    </message>
    <message>
        <source>Suspending in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Vänteläge om &lt;b&gt;%1&lt;/b&gt; sekunder</translation>
    </message>
    <message>
        <source>Hibernating in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Viloläge om &lt;b&gt;%1&lt;/b&gt; sekunder</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <source>Play Selected Range</source>
        <translation>Spela up det markerade intervallet</translation>
    </message>
    <message>
        <source>Begin</source>
        <extracomment>noun, the beginning of the video</extracomment>
        <translation>Början</translation>
    </message>
    <message>
        <source>End</source>
        <extracomment>noun, the end of the video</extracomment>
        <translation>Slut</translation>
    </message>
    <message>
        <source>Play %1~%2</source>
        <extracomment>play the video from time %1 to time %2. %1 and %2 are time in hh:mm:ss format.</extracomment>
        <translation>Spela upp %1~%2</translation>
    </message>
    <message>
        <source>Video Preview</source>
        <translation>Förhandsgranska video</translation>
    </message>
</context>
<context>
    <name>TimeRangeEdit</name>
    <message>
        <source>From Begin</source>
        <translation>Från början</translation>
    </message>
    <message>
        <source>To End</source>
        <translation>Till slutet</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Show &amp;Release Notes</source>
        <translation>Visa &amp;versionsnotiser</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Sök efter uppdateringar vid programstart</translation>
    </message>
    <message>
        <source>Downloading update information...</source>
        <translation>Laddar ner uppdateringsinformation...</translation>
    </message>
    <message>
        <source>Cannot connect to server.</source>
        <translation>Kan inte ansluta till servern.</translation>
    </message>
    <message>
        <source>Failed to parse the received data.</source>
        <translation>Kunde inte tolka mottagen data.</translation>
    </message>
    <message>
        <source>You are already using the latest version of MystiQ.</source>
        <translation>Du använder redan den senaste versionen av MystiQ.</translation>
    </message>
    <message>
        <source>An unknown error has occurred.</source>
        <translation>Ett okänt fel har inträffat.</translation>
    </message>
    <message>
        <source>A new version of MystiQ has been released!</source>
        <translation>En ny version av MystiQ har släppts!</translation>
    </message>
    <message>
        <source>Version &lt;b&gt;%1&lt;/b&gt; is available at %2.</source>
        <extracomment>%1 is version number, %2 is the project homepage</extracomment>
        <translation>Version &lt;b&gt;%1&lt;/b&gt; finns tillgänglig på %2.</translation>
    </message>
    <message>
        <source>You can download this version using the link:</source>
        <translation>Du kan ladda ner den här versionen via länken:</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation>Kolla Uppdatering</translation>
    </message>
    <message>
        <source>The current version you are using is newer than the release channel version.&lt;br&gt;Therefore, you are using the development channel.</source>
        <translation>Den version du nu använder är nyare än publiceringskanalens version.&lt;br&gt;Därför använder du utvecklingskanalen.</translation>
    </message>
</context>
</TS>
